@@ -1,21 +1,19 @@
 import asyncio
-from collections import deque, namedtuple
 import itertools
 import logging
 import os
 import threading
-import weakref
 import warnings
+import weakref
+from collections import deque, namedtuple
 
 from tornado.concurrent import Future
 from tornado.ioloop import IOLoop
 
 from ..protocol import nested_deserialize
 from ..utils import get_ip
-
+from .core import Comm, CommClosedError, Connector, Listener
 from .registry import Backend, backends
-from .core import Comm, Connector, Listener, CommClosedError
-
 
 logger = logging.getLogger(__name__)
 
@@ -36,13 +34,16 @@ class Manager:
             # Avoid immediate warning for unreachable network
             # (will still warn for other get_ip() calls when actually used)
             warnings.simplefilter("ignore")
-            self.ip = get_ip()
+            try:
+                self.ip = get_ip()
+            except OSError:
+                self.ip = "127.0.0.1"
         self.lock = threading.Lock()
 
     def add_listener(self, addr, listener):
         with self.lock:
             if addr in self.listeners:
-                raise RuntimeError("already listening on %r" % (addr,))
+                raise RuntimeError(f"already listening on {addr!r}")
             self.listeners[addr] = listener
 
     def remove_listener(self, addr):
@@ -169,7 +170,7 @@ class InProc(Comm):
 
     def _get_finalizer(self):
         def finalize(write_q=self._write_q, write_loop=self._write_loop, r=repr(self)):
-            logger.warning("Closing dangling queue in %s" % (r,))
+            logger.warning(f"Closing dangling queue in {r}")
             write_loop.add_callback(write_q.put_nowait, _EOF)
 
         return finalize
@@ -184,13 +185,13 @@ class InProc(Comm):
 
     async def read(self, deserializers="ignored"):
         if self._closed:
-            raise CommClosedError
+            raise CommClosedError()
 
         msg = await self._read_q.get()
         if msg is _EOF:
             self._closed = True
             self._finalizer.detach()
-            raise CommClosedError
+            raise CommClosedError()
 
         if self.deserialize:
             msg = nested_deserialize(msg)
@@ -198,7 +199,7 @@ class InProc(Comm):
 
     async def write(self, msg, serializers=None, on_error=None):
         if self.closed():
-            raise CommClosedError
+            raise CommClosedError()
 
         # Ensure we feed the queue in the same thread it is read from.
         self._write_loop.add_callback(self._write_q.put_nowait, msg)
@@ -260,6 +261,11 @@ class InProcListener(Listener):
             )
             # Notify connector
             conn_req.c_loop.add_callback(conn_req.conn_event.set)
+            try:
+                await self.on_connection(comm)
+            except CommClosedError:
+                logger.debug("Connection closed before handshake completed")
+                return
             IOLoop.current().add_callback(self.comm_handler, comm)
 
     def connect_threadsafe(self, conn_req):
@@ -290,7 +296,7 @@ class InProcConnector(Connector):
     async def connect(self, address, deserialize=True, **connection_args):
         listener = self.manager.get_listener_for(address)
         if listener is None:
-            raise IOError("no endpoint for inproc address %r" % (address,))
+            raise OSError(f"no endpoint for inproc address {address!r}")
 
         conn_req = ConnectionRequest(
             c2s_q=Queue(),
