@@ -20,11 +20,12 @@ from tornado.tcpclient import TCPClient
 from tornado.tcpserver import TCPServer
 
 import dask
+from dask.utils import parse_timedelta
 
 from ..protocol.utils import pack_frames_prelude, unpack_frames
 from ..system import MEMORY_LIMIT
 from ..threadpoolexecutor import ThreadPoolExecutor
-from ..utils import ensure_ip, get_ip, get_ipv6, nbytes, parse_timedelta
+from ..utils import ensure_ip, get_ip, get_ipv6, nbytes
 from .addressing import parse_host_port, unparse_host_port
 from .core import Comm, CommClosedError, Connector, FatalCommClosedError, Listener
 from .registry import Backend, backends
@@ -91,7 +92,7 @@ def set_tcp_timeout(comm):
             logger.debug("Setting TCP user timeout: %d ms", timeout * 1000)
             TCP_USER_TIMEOUT = 18  # since Linux 2.6.37
             sock.setsockopt(socket.SOL_TCP, TCP_USER_TIMEOUT, timeout * 1000)
-    except EnvironmentError as e:
+    except OSError as e:
         logger.warning("Could not set timeout on TCP stream: %s", e)
 
 
@@ -104,7 +105,7 @@ def get_stream_address(comm):
 
     try:
         return unparse_host_port(*comm.socket.getsockname()[:2])
-    except EnvironmentError:
+    except OSError:
         # Probably EBADF
         return "<closed>"
 
@@ -118,14 +119,10 @@ def convert_stream_closed_error(obj, exc):
         exc = exc.real_error
         if ssl and isinstance(exc, ssl.SSLError):
             if "UNKNOWN_CA" in exc.reason:
-                raise FatalCommClosedError(
-                    "in %s: %s: %s" % (obj, exc.__class__.__name__, exc)
-                )
-        raise CommClosedError(
-            "in %s: %s: %s" % (obj, exc.__class__.__name__, exc)
-        ) from exc
+                raise FatalCommClosedError(f"in {obj}: {exc.__class__.__name__}: {exc}")
+        raise CommClosedError(f"in {obj}: {exc.__class__.__name__}: {exc}") from exc
     else:
-        raise CommClosedError("in %s: %s" % (obj, exc)) from exc
+        raise CommClosedError(f"in {obj}: {exc}") from exc
 
 
 def _close_comm(ref):
@@ -303,7 +300,7 @@ class TCP(Comm):
                 if stream.writing():
                     yield stream.write(b"")
                 stream.socket.shutdown(socket.SHUT_RDWR)
-            except EnvironmentError:
+            except OSError:
                 pass
             finally:
                 self._finalizer.detach()
@@ -451,7 +448,7 @@ class BaseTCPListener(Listener, RequireEncryptionMixin):
                 sockets = netutil.bind_sockets(
                     self.port, address=self.ip, backlog=backlog
                 )
-            except EnvironmentError as e:
+            except OSError as e:
                 # EADDRINUSE can happen sporadically when trying to bind
                 # to an ephemeral port
                 if self.port != 0 or e.errno != errno.EADDRINUSE:
@@ -544,7 +541,7 @@ class TLSListener(BaseTCPListener):
     async def _prepare_stream(self, stream, address):
         try:
             await stream.wait_for_handshake()
-        except EnvironmentError as e:
+        except OSError as e:
             # The handshake went wrong, log and ignore
             logger.warning(
                 "Listener on %r: TLS handshake failed with remote %r: %s",
