@@ -1,7 +1,6 @@
 import pytest
 
 from distributed.deploy.cluster import Cluster
-from distributed.utils_test import cleanup  # noqa: F401
 
 
 @pytest.mark.asyncio
@@ -26,3 +25,10 @@ async def test_repr(cleanup):
     res = repr(cluster)
     expected = "Cluster(A, '<Not Connected>', workers=0, threads=0, memory=0 B)"
     assert res == expected
+
+
+@pytest.mark.asyncio
+async def test_logs_deprecated(cleanup):
+    cluster = Cluster(asynchronous=True)
+    with pytest.warns(FutureWarning, match="get_logs"):
+        cluster.logs()
