@@ -1,12 +1,13 @@
 import asyncio
+from datetime import timedelta
 from time import sleep
 
 import pytest
 import tlz as toolz
 
-from distributed import Pub, Sub, wait, get_worker, TimeoutError
-from distributed.utils_test import gen_cluster
+from distributed import Pub, Sub, TimeoutError, get_worker, wait
 from distributed.metrics import time
+from distributed.utils_test import gen_cluster
 
 
 @gen_cluster(client=True, timeout=None)
@@ -36,7 +37,7 @@ async def test_speed(c, s, a, b):
             #     print(a, b, i)
         return n
 
-    import numpy as np
+    np = pytest.importorskip("numpy")
 
     x = np.random.random(1000)
 
@@ -120,11 +121,11 @@ async def test_timeouts(c, s, a, b):
     sub = Sub("a", client=c, worker=None)
     start = time()
     with pytest.raises(TimeoutError):
-        await sub.get(timeout=0.1)
+        await sub.get(timeout="100ms")
     stop = time()
     assert stop - start < 1
     with pytest.raises(TimeoutError):
-        await sub.get(timeout=0.01)
+        await sub.get(timeout=timedelta(milliseconds=10))
 
 
 @gen_cluster(client=True)
@@ -137,7 +138,7 @@ async def test_repr(c, s, a, b):
     assert "Sub" in str(sub)
 
 
-@pytest.mark.xfail(reason="out of order execution")
+@pytest.mark.xfail(reason="flaky and re-fails on reruns; out of order execution")
 @gen_cluster(client=True)
 async def test_basic(c, s, a, b):
     async def publish():
